@@ -53,8 +53,7 @@ class TimeItemDescriptor(object):
 class SubRipTime(Comparable):
     TIME_PATTERN = '%02d:%02d:%02d,%03d'
     TIME_REPR = 'SubRipTime(%d, %d, %d, %d)'
-    RE_TIME = re.compile(r'(?P<hours>\d{2}):(?P<minutes>\d{2}):'
-                         r'(?P<seconds>\d{2})[,\.](?P<milliseconds>\d{3})')
+    RE_TIME_SEP = re.compile(r'\:|\.|\,')
     SECONDS_RATIO = 1000
     MINUTES_RATIO = SECONDS_RATIO * 60
     HOURS_RATIO = MINUTES_RATIO * 60
@@ -89,20 +88,20 @@ class SubRipTime(Comparable):
         return self.TIME_PATTERN % tuple(self)
 
     def __cmp__(self, other):
-        return cmp(self.ordinal, self._coerce(other).ordinal)
+        return cmp(self.ordinal, self.coerce(other).ordinal)
 
     def __add__(self, other):
-        return self.from_ordinal(self.ordinal + self._coerce(other).ordinal)
+        return self.from_ordinal(self.ordinal + self.coerce(other).ordinal)
 
     def __iadd__(self, other):
-        self.ordinal += self._coerce(other).ordinal
+        self.ordinal += self.coerce(other).ordinal
         return self
 
     def __sub__(self, other):
-        return self.from_ordinal(self.ordinal - self._coerce(other).ordinal)
+        return self.from_ordinal(self.ordinal - self.coerce(other).ordinal)
 
     def __isub__(self, other):
-        self.ordinal -= self._coerce(other).ordinal
+        self.ordinal -= self.coerce(other).ordinal
         return self
 
     def __mul__(self, ratio):
@@ -113,7 +112,7 @@ class SubRipTime(Comparable):
         return self
 
     @classmethod
-    def _coerce(cls, other):
+    def coerce(cls, other):
         """
         Coerce many types to SubRipTime instance.
         Supported types:
@@ -125,11 +124,11 @@ class SubRipTime(Comparable):
         """
         if isinstance(other, SubRipTime):
             return other
-        elif isinstance(other, basestring):
+        if isinstance(other, basestring):
             return cls.from_string(other)
-        elif isinstance(other, (int, long)):
+        if isinstance(other, (int, long)):
             return cls.from_ordinal(other)
-        elif isinstance(other, time):
+        if isinstance(other, time):
             return cls.from_time(other)
         try:
             return cls(**other)
@@ -165,11 +164,10 @@ class SubRipTime(Comparable):
         str/unicode(HH:MM:SS,mmm) -> SubRipTime corresponding to serial
         raise InvalidTimeString
         """
-        match = cls.RE_TIME.match(source)
-        if not match:
+        items = cls.RE_TIME_SEP.split(source)
+        if len(items) != 4:
             raise InvalidTimeString
-        items = dict((k, int(v)) for k, v in match.groupdict().items())
-        return cls(**items)
+        return cls(*(int(i) for i in items))
 
     @classmethod
     def from_time(cls, source):
